@@ -8,6 +8,8 @@
 #include <QtMqtt/QMqttClient>
 #include <QtWidgets/QMessageBox>
 
+using namespace Qt::StringLiterals;
+
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
     ui(new Ui::MainWindow)
@@ -23,18 +25,17 @@ MainWindow::MainWindow(QWidget *parent) :
 
     connect(m_client, &QMqttClient::messageReceived, this, [this](const QByteArray &message, const QMqttTopicName &topic) {
         const QString content = QDateTime::currentDateTime().toString()
-                    + QLatin1String(" Received Topic: ")
+                    + " Received Topic: "_L1
                     + topic.name()
-                    + QLatin1String(" Message: ")
+                    + " Message: "_L1
                     + message
-                    + QLatin1Char('\n');
+                    + u'\n';
         ui->editLog->insertPlainText(content);
     });
 
     connect(m_client, &QMqttClient::pingResponseReceived, this, [this]() {
         const QString content = QDateTime::currentDateTime().toString()
-                    + QLatin1String(" PingResponse")
-                    + QLatin1Char('\n');
+                    + "PingResponse\n"_L1;
         ui->editLog->insertPlainText(content);
     });
 
@@ -71,9 +72,9 @@ void MainWindow::on_buttonQuit_clicked()
 void MainWindow::updateLogStateChange()
 {
     const QString content = QDateTime::currentDateTime().toString()
-                    + QLatin1String(": State Change")
+                    + ": State Change"_L1
                     + QString::number(m_client->state())
-                    + QLatin1Char('\n');
+                    + u'\n';
     ui->editLog->insertPlainText(content);
 }
 
@@ -92,14 +93,15 @@ void MainWindow::setClientPort(int p)
 void MainWindow::on_buttonPublish_clicked()
 {
     if (m_client->publish(ui->lineEditTopic->text(), ui->lineEditMessage->text().toUtf8()) == -1)
-        QMessageBox::critical(this, QLatin1String("Error"), QLatin1String("Could not publish message"));
+        QMessageBox::critical(this, u"Error"_s, u"Could not publish message"_s);
 }
 
 void MainWindow::on_buttonSubscribe_clicked()
 {
     auto subscription = m_client->subscribe(ui->lineEditTopic->text());
     if (!subscription) {
-        QMessageBox::critical(this, QLatin1String("Error"), QLatin1String("Could not subscribe. Is there a valid connection?"));
+        QMessageBox::critical(this, u"Error"_s,
+                              u"Could not subscribe. Is there a valid connection?"_s);
         return;
     }
 }
